==> hs-data-pprint-0.2.1.4_2.txz: usr/local/lib/cabal/ghc-7.6.3/data-pprint-0.2.1.4/register.sh <==
#!/bin/sh
echo 'name: data-pprint
version: 0.2.1.4
id: data-pprint-0.2.1.4-688826d8948c55b9d8c30925738dab21

license: BSD3
copyright:
maintainer: divip@aszt.inf.elte.hu
stability: beta
homepage:
package-url:
synopsis: Prettyprint and compare Data values
description: Prettyprint and compare Data values.
             .
             *   Size limit for the output
             .
             *   Time limit for the computation
             .
             *   Escape exceptions
             .
             *   Do not escape unicode characters
             .
             *   Comparison: Highlight the first difference
             .
             *   Comparison: Yes, No or Maybe results
             .
             Probably you need only the '\''pprint'\'' and '\''(===)'\'' functions from the "Data.PPrint" module.
             .
             Usage examples:
             .
             > pprint [1..]
             > pprint $ repeat [1..]
             > pprint $ iterate (*10) 1
             > pprint $ map length $ replicate 5 [1..] ++ repeat []
             > pprint [2 `div` 0, error "xxx", 18, 4 `div` 0]
             > [1..10] === reverse [10,9..1]
             > [1..10] === reverse [10..1]
             > reverse [10..] === [1..]
             > [1..] === [1..99] ++ [101..]
             > ([1..], [1..]) === ([1..], [1..100])
             > (error "x", [1..]) === (0 `div` 0, reverse [1..])
             > error ("xx" ++ show (length [1..])) === 1
             > error ("xx" ++ error "yy") === 1
             > (error $ unlines $ replicate 300 "xxxxxxxxxxxxxxxxxxxxxxxxxxx") === 1
             > pprint ['\''a'\''..]
             > pprint $ "hello" ++ [error "x"] ++ "world!"
             .
             See also <http://pnyf.inf.elte.hu/fp/Show_en.xml>
             .
             Changes since 0.1: Refactoring, proper handling of nested errors
category: Testing, Text
author: Péter Diviánszky
exposed: True
exposed-modules: Data.PPrint Data.Data.Eval Data.Data.Compare
                 Data.Data.GenRep Data.Data.GenRep.Functions Data.Data.GenRep.Doc
                 Control.Exception.Pure System.SimpleTimeout
                 System.SimpleTimeout.Limits System.IO.Parallel
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/data-pprint-0.2.1.4
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/data-pprint-0.2.1.4
              /usr/local/lib
hs-libraries: HSdata-pprint-0.2.1.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
         parallel-3.2.0.3-d6c020cb3aa15c71f5f29c0db359fd39
         pretty-1.1.1.0-66181c695e6a2e173ba2088cf55cc396
         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/data-pprint-0.2.1.4/html/data-pprint.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/data-pprint-0.2.1.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-data-pprint-0.2.3_1.txz: usr/local/lib/cabal/ghc-7.8.3/data-pprint-0.2.3/register.sh <==
#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: data-pprint
version: 0.2.3
id: data-pprint-0.2.3-26165b49ba945db1762e8a0e8ef8fc91

license: BSD3
copyright:
maintainer: divipp@gmail.com
stability: beta
homepage:
package-url:
synopsis: Prettyprint and compare Data values
description: Prettyprint and compare Data values.
             .
             *   Size limit for the output
             .
             *   Time limit for the computation
             .
             *   Escape exceptions
             .
             *   Do not escape unicode characters
             .
             *   Comparison: Highlight the first difference
             .
             *   Comparison: Yes, No or Maybe results
             .
             Probably you need only the '\''pprint'\'' and '\''(===)'\'' functions from the "Data.PPrint" module.
             .
             Usage examples:
             .
             > pprint [1..]
             > pprintTo 10000 $ repeat [1..]
             > pprint $ iterate (*10) 1
             > pprint $ map length $ replicate 5 [1..] ++ repeat []
             > pprint [2 `div` 0, error "xxx", 18, 4 `div` 0]
             > [1..10] === reverse [10,9..1]
             > [1..10] === reverse [10..1]
             > reverse [10..] === [1..]
             > [1..] === [1..99] ++ [101..]
             > ([1..], [1..]) === ([1..], [1..100])
             > (error "x", [1..]) === (0 `div` 0, reverse [1..])
             > error ("xx" ++ show (length [1..])) === 1
             > error ("xx" ++ error "yy") === 1
             > (error $ unlines $ replicate 300 "xxxxxxxxxxxxxxxxxxxxxxxxxxx") === 1
             > pprint ['\''a'\''..]
             > pprint $ "hello" ++ [error "x"] ++ "world!"
             .
             See also <http://pnyf.inf.elte.hu/fp/Show_en.xml>
             .
             Changes since 0.1: Refactoring, proper handling of nested errors
category: Testing, Text
author: Péter Diviánszky
exposed: True
exposed-modules: Data.PPrint Data.Data.Eval Data.Data.Compare
                 Data.Data.GenRep Data.Data.GenRep.Functions Data.Data.GenRep.Doc
                 Control.Exception.Pure System.SimpleTimeout
                 System.SimpleTimeout.Limits System.IO.Parallel
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/data-pprint-0.2.3
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/data-pprint-0.2.3
              /usr/local/lib
hs-libraries: HSdata-pprint-0.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         deepseq-1.3.0.2-733fe43e121f761739636bd6670bea77
         mtl-2.1.3.1-8bcc0591131896cfc8761a93703d4c61
         parallel-3.2.0.4-e7d84d2578e6412ec995ab7b1bd5ca95
         pretty-1.1.1.1-055fb3b6b88c48ad1bf91e5cf35828d1
         time-1.4.2-9927ada6d5503e0b70e51a11902c8b61
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/data-pprint-0.2.3/html/data-pprint.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/data-pprint-0.2.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
